local

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 21, 2025 License: AGPL-3.0 Imports: 13 Imported by: 1

Documentation

Index

Constants

const (
	Local_Register_FullMethodName   = "/local.v1.Local/Register"
	Local_Deregister_FullMethodName = "/local.v1.Local/Deregister"
)

Variables

var File_local_proto protoreflect.FileDescriptor
var Local_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "local.v1.Local",
	HandlerType: (*LocalServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Register",
			Handler:    _Local_Register_Handler,
		},
		{
			MethodName: "Deregister",
			Handler:    _Local_Deregister_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "local.proto",
}

Local_ServiceDesc is the grpc.ServiceDesc for Local service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterLocalServer

func RegisterLocalServer(s grpc.ServiceRegistrar, srv LocalServer)

Types

type DeregisterReply

type DeregisterReply struct {
	Confirmed bool `protobuf:"varint,1,opt,name=confirmed,proto3" json:"confirmed,omitempty"`
	// contains filtered or unexported fields
}

func (*DeregisterReply) Descriptor deprecated

func (*DeregisterReply) Descriptor() ([]byte, []int)

Deprecated: Use DeregisterReply.ProtoReflect.Descriptor instead.

func (*DeregisterReply) GetConfirmed

func (x *DeregisterReply) GetConfirmed() bool

func (*DeregisterReply) ProtoMessage

func (*DeregisterReply) ProtoMessage()

func (*DeregisterReply) ProtoReflect

func (x *DeregisterReply) ProtoReflect() protoreflect.Message

func (*DeregisterReply) Reset

func (x *DeregisterReply) Reset()

func (*DeregisterReply) String

func (x *DeregisterReply) String() string

type DeregisterRequest

type DeregisterRequest struct {
	Vpc           string   `protobuf:"bytes,1,opt,name=vpc,proto3" json:"vpc,omitempty"`
	Vpcattachment string   `protobuf:"bytes,2,opt,name=vpcattachment,proto3" json:"vpcattachment,omitempty"`
	Networks      []string `protobuf:"bytes,3,rep,name=networks,proto3" json:"networks,omitempty"`
	// contains filtered or unexported fields
}

func (*DeregisterRequest) Descriptor deprecated

func (*DeregisterRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeregisterRequest.ProtoReflect.Descriptor instead.

func (*DeregisterRequest) GetNetworks

func (x *DeregisterRequest) GetNetworks() []string

func (*DeregisterRequest) GetVpc

func (x *DeregisterRequest) GetVpc() string

func (*DeregisterRequest) GetVpcattachment

func (x *DeregisterRequest) GetVpcattachment() string

func (*DeregisterRequest) ProtoMessage

func (*DeregisterRequest) ProtoMessage()

func (*DeregisterRequest) ProtoReflect

func (x *DeregisterRequest) ProtoReflect() protoreflect.Message

func (*DeregisterRequest) Reset

func (x *DeregisterRequest) Reset()

func (*DeregisterRequest) String

func (x *DeregisterRequest) String() string

type Local

type Local struct {
	UnimplementedLocalServer
	SocketPath        string
	RegisterHandler   func(string, string, []string) error
	DeregisterHandler func(string, string, []string) error
}

func (*Local) Deregister

func (l *Local) Deregister(ctx context.Context, req *DeregisterRequest) (*DeregisterReply, error)

func (*Local) Register

func (l *Local) Register(ctx context.Context, req *RegisterRequest) (*RegisterReply, error)

func (*Local) Serve

func (l *Local) Serve(ctx context.Context) error

type LocalClient

type LocalClient interface {
	Register(ctx context.Context, in *RegisterRequest, opts ...grpc.CallOption) (*RegisterReply, error)
	Deregister(ctx context.Context, in *DeregisterRequest, opts ...grpc.CallOption) (*DeregisterReply, error)
}

LocalClient is the client API for Local service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewLocalClient

func NewLocalClient(cc grpc.ClientConnInterface) LocalClient

type LocalServer

type LocalServer interface {
	Register(context.Context, *RegisterRequest) (*RegisterReply, error)
	Deregister(context.Context, *DeregisterRequest) (*DeregisterReply, error)
	// contains filtered or unexported methods
}

LocalServer is the server API for Local service. All implementations must embed UnimplementedLocalServer for forward compatibility.

type RegisterReply

type RegisterReply struct {
	Confirmed bool `protobuf:"varint,1,opt,name=confirmed,proto3" json:"confirmed,omitempty"`
	// contains filtered or unexported fields
}

func (*RegisterReply) Descriptor deprecated

func (*RegisterReply) Descriptor() ([]byte, []int)

Deprecated: Use RegisterReply.ProtoReflect.Descriptor instead.

func (*RegisterReply) GetConfirmed

func (x *RegisterReply) GetConfirmed() bool

func (*RegisterReply) ProtoMessage

func (*RegisterReply) ProtoMessage()

func (*RegisterReply) ProtoReflect

func (x *RegisterReply) ProtoReflect() protoreflect.Message

func (*RegisterReply) Reset

func (x *RegisterReply) Reset()

func (*RegisterReply) String

func (x *RegisterReply) String() string

type RegisterRequest

type RegisterRequest struct {
	Vpc           string   `protobuf:"bytes,1,opt,name=vpc,proto3" json:"vpc,omitempty"`
	Vpcattachment string   `protobuf:"bytes,2,opt,name=vpcattachment,proto3" json:"vpcattachment,omitempty"`
	Networks      []string `protobuf:"bytes,3,rep,name=networks,proto3" json:"networks,omitempty"`
	// contains filtered or unexported fields
}

func (*RegisterRequest) Descriptor deprecated

func (*RegisterRequest) Descriptor() ([]byte, []int)

Deprecated: Use RegisterRequest.ProtoReflect.Descriptor instead.

func (*RegisterRequest) GetNetworks

func (x *RegisterRequest) GetNetworks() []string

func (*RegisterRequest) GetVpc

func (x *RegisterRequest) GetVpc() string

func (*RegisterRequest) GetVpcattachment

func (x *RegisterRequest) GetVpcattachment() string

func (*RegisterRequest) ProtoMessage

func (*RegisterRequest) ProtoMessage()

func (*RegisterRequest) ProtoReflect

func (x *RegisterRequest) ProtoReflect() protoreflect.Message

func (*RegisterRequest) Reset

func (x *RegisterRequest) Reset()

func (*RegisterRequest) String

func (x *RegisterRequest) String() string

type UnimplementedLocalServer

type UnimplementedLocalServer struct{}

UnimplementedLocalServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedLocalServer) Deregister

func (UnimplementedLocalServer) Register

type UnsafeLocalServer

type UnsafeLocalServer interface {
	// contains filtered or unexported methods
}

UnsafeLocalServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LocalServer will result in compilation errors.

Jump to